function []=diagnose(filename)
%
% To read SWR files for a particular Heating transmitter and array
%  and extract some usefile diagnostic info like:
%  1) Total time taken where unusually long times are most likley a 
%     sign of a slow capacitor movement. 
%  2) Average ratio of Pa/P and std dev
%  3) 
%
%  20121112   MTR
%                                                          
%
%=================================================================

hold off
close
summary_file='diagnosis-summary.txt'

an=input('Which array number ?','s');
at=input('Which transmitter number ?','s');
ststart=strcat('/data/swrlogs/A',an,'T',at,'_*.*')
oldformat=0;
nargin=input('Do you want to process all files [1=Y, 0=N] ?')
if nargin<1 
  [filename, pathname, filterindex] = uigetfile(ststart, 'Pick an ascii data file', 'A');
  sfilen=filename;
  filename=fullfile(pathname,filename);
  filelist=dir(filename)
else
  filelist=dir(ststart);
end

nfiles=numel(filelist)
filelist;

for fn=1:nfiles
  filename=filelist(fn).name
  sfilen=filename;

  fid1=fopen(summary_file, 'A');
  
  [h h2 h3 oldformat A f1]=read_swr(filename);

  if h(1,1:6) == 'Array:'
    oldformat=1;
    arrnum=strread(h(2,:),'%d');
    txnum =strread(h(4,:),'%d');
    dat=strcat(h2(1),' ', h2(2),' ', h2(3));
    ondate=char(strcat(h2(1),'-',h2(2),'-',h2(3)));
    ontime= char(h3(1,1));
    tit=strcat(['Array: ',num2str(arrnum,2),' Tx: ',num2str(txnum,2),'  on: ',ondate,blanks(1),ontime]);

    %[find(A(:,3) <0.1 )];      % finds cases with power < 0.1 kW
    [A([find(A(:,3) <0.1 )],2)]=NaN;
    t=NaN;
    pa= A(:,3);
    s=size(pa);
    if (datenum(dat)-datenum('04 Jun 2003') >0)
      p=A(:,9); 
    else
      p=NaN*[1:s(1)];
    end
    dat=ondate;
  else
    arrnum=strread(h(2,:),'%d');
    [dum txnum] =strread(h(4,:),'%c%d');
    tit=strcat(['Array: ',num2str(arrnum,2),' Tx: ',num2str(txnum,2),'  on: ',h(6,:),blanks(1),h(7,:)]);

    %[find(A(:,3) <0.1 )];      % finds cases with power < 0.1 kW
    [A([find(A(:,3) <0.1 )],2)]=NaN;
    Adims=size(A);
    fp=f1{6};
    lp=f1{7};
    ondate=[fp ' ' lp];
    lp=f1{11};
    offdate=[fp ' ' lp];
    t=((datenum(offdate)-datenum(ondate))*24*60*60);
    p= A(:,3);
    pa=A(:,4);
    s=size(p);
    i=1;
    dat=h(6,1:11);
  end

% Calulate the avearge ratio of analogue power(pa above or Pt on board P3) to power calculated
% from Uv and Ur
  i=1;
  for n = 1:s(1)
    pr(i)=NaN;
    if (p(n)>0 && pa(n)>0)
       pr(i)=pa(n)/p(n);
       i=i+1;
    end
  end
  prsize=i-1
  meanPratio=mean(pr(1:prsize));
  stdPratio=std(pr(1:prsize));

%ondate
  fprintf('%s%12s',sfilen,dat);
  fprintf('%s%0.1f%s%3.0d',' Time_taken: ',t,'s nfreqs= ',s(1));
  fprintf('%s%0.2f%s%0.2f\n',' Panalog/P= ',meanPratio,' stdP=',stdPratio);

  fprintf(fid1,'%-28s%12s',sfilen,dat);
  fprintf(fid1,'%12s%5.1f%10s%3.0d',' Time_taken: ',t,'s nfreqs= ',s(1));
  fprintf(fid1,'%12s%4.2f%s%4.2f\n',' Panalog/P= ',meanPratio,' stdP= ',stdPratio);
  fclose(fid1);
end

% SWR files after 4 June 2003 have the second power also in the last column,
% labelled as Poutput. (But note the error in the comment line
% to the the data taking program ZSWR3.IBW hwere it says Poutput comes from
% Pt on board P3. This is the analogue power. Poutput is calculated in the
% code from Uf and Ur. 

end
